
# Type: alias


the name used for a slot in the context of its owning class.  If present, this is used instead of the actual slot name.

URI: [meta:alias](https://w3id.org/biolink/biolinkml/meta/alias)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
